=====
Views
=====

If you wish to include unsubscribe links in your notification emails
(recommended) and you happen to be using Jinja templates, you can point them to
the provided :func:`~tidings.views.unsubscribe` view:

.. autofunction:: tidings.views.unsubscribe

A stock anonymous-watch-confirmation view is planned for a future version of
tidings.
